@@ -1,7 +1,7 @@
 import rel, optparse
 
 def parse_input():
-    parser = optparse.OptionParser()
+    parser = optparse.OptionParser('dez_test [-m MODULE]')
     parser.add_option("-p", "--port", dest="port", default="80", help="run test on PORT. default: 8888")
     parser.add_option("-d", "--domain", dest="domain", default="localhost", help="run test on DOMAIN. default: localhost")
     parser.add_option("-m", "--module", dest="module", help="test MODULE. required field. options: app_proxy, django_hello_world, echo_server, get_url, hello_client, http_client, http_client2, httpd_hello_world, http_proxy, new_conn, op_callback_server, op_callback_test, op_test, stomp_test, wsgi_test")
